<?php

namespace App;

use Illuminate\Database\Eloquent\Relations\BelongsTo;

class Child extends Translatable
{
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable=[
        'name',
        'date_of_birth',
        'kicks',
        'parent_id',
    ];

    /**
     * The attributes that are translatable
     *
     * @var array
     */
    protected $translatable=[
        'name',
    ];

    /**
     * The relationships that should always be loaded.
     *
     * @var array
     */
    protected $with=['parent'];

    /************************************************************************/
    /****************************** Relations *******************************/
    /************************************************************************/

    /**
     * parent Relationship.
     *
     * @return BelongsTo
     **/

    public function parent() : BelongsTo
    {
        return $this->belongsTo(User::class,'parent_id','id');
    }

    /**
     * This attribute function for returning the value of Name.  => { name_val }
     * Used only at [ Show Mode ]
     *
     * @var String
     */
    public function getNameValAttribute()
    {
        return $this->attributes['name'] ? VarByLang(getData(collect($this),"name")) : 'N/A';
    }
}
