<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;

class Clinic extends Translatable
{
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable=[
        'name',
        'address',
        'description',
        'mobile',
        'whats',
        'facebook',
        'instgram',
        'youtube',
        'lat',
        'long',
        'location',
        'zoom',
        'logo'
    ];
    /**
     * The attributes that are translatable
     *
     * @var array
     */
    protected $translatable=[
        'name',
        'address',
        'description'
    ];
    /************************************************************************/
    /****************************** Relations *******************************/
    /************************************************************************/
    /**
     * patientTypes Relationship.
     *
     * @return BelongsToMany
     **/

    public function patientTypes() : BelongsToMany
    {
        return $this->belongsToMany(PatientType::class,'clinic_patient_types','clinic_id','patient_type_id')->withPivot(['price']);
    }
    /**
     * clinicWorkingDays Relationship.
     *
     * @return HasMany
     **/

    public function workingDays() : HasMany
    {
        return $this->hasMany(ClinicWorkingDays::class,'clinic_id','id');
    }
    /**
     * This attribute function for returning the value of Name.  => { name_val }
     * Used only at [ Show Mode ]
     *
     * @var String
     */
    public function getNameValAttribute()
    {
        return $this->attributes['name'] ? VarByLang(getData(collect($this),"name")) : 'N/A';
    }
    /**
     * This attribute function for returning the value of Name.  => { description_val }
     * Used only at [ Show Mode ]
     *
     * @var String
     */
    public function getDescriptionValAttribute()
    {
        return $this->attributes['description'] ? VarByLang(getData(collect($this),"description")) : 'N/A';
    }
    /**
     * This attribute function for returning the value of Name.  => { address_val }
     * Used only at [ Show Mode ]
     *
     * @var String
     */
    public function getAddressValAttribute()
    {
        return $this->attributes['address'] ? VarByLang(getData(collect($this),"address")) : 'N/A';
    }

}
