<?php

namespace App\Datatables;
use App\Booking;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Services\DataTable;

class ViewToDoctorDataTables extends DataTable
{
    use BuilderParameters;

    /**
     * Build DataTable class.
     *
     * @param mixed $query Results from query() method.
     * @return \Yajra\DataTables\DataTableAbstract
     */
    public function dataTable($query)
    {
        return datatables()
            ->eloquent($query)
            ->editColumn('checkbox', $this->getColumnCheckboxHtml())
            ->editColumn("name",function ($model){
                if($model->patient) {
                    $view    = sprintf('<a href="%s" class="btn btn-sm btn-clean btn-icon btn-icon-md width_hover" onclick="quickViewEntity(' . $model->patient_id . ')"  title="%s">%s</a>','#',$model->patient->name,$model->patient->name);
                    return $view;
                }
                else{
                    return $model->patient?$model->patient->name:$model->name;
                }
            })
            ->editColumn('patientType.name', function ($model) {
                return $model->patientType?$model->patientType->name_val:"N/A";
            })
            ->editColumn('slot_number', function ($model) {
                return $model->patient?$model->patient->bookings()->whereNotNull('attendance_at')->count():"N/A";
            })
            ->editColumn('actions',function($model){
                $cancel_attendance  = sprintf('<a data-id="'.$model->id.'" id="cancel_attendance_'.$model->id.'" class="SpeakerDelete btn btn-sm btn-clean btn-icon btn-icon-md"  title="%s"><i class="la la-share"></i></a>',__('main.cancel_view_to_doctor'));
                $cancel_attendance.=sprintf('
                        <script defer>
                            $("#cancel_attendance_%s").on("click",(e)=>{
                                swal.fire({
                                    title: "%s",
                                    text: "%s",
                                    type: "info",
                                    showCancelButton: true,
                                    confirmButtonText: "%s",
                                    cancelButtonText: "%s",
                                    reverseButtons: true
                                }).then(function(result){
                                    if (result.value) {
                                        axios.get("%s").then((res) => {
                                            if (res.data.success) {
                                                swal.fire("%s", "%s", "success");
                                                setTimeout(() => {
                                                    window.location = "%s";
                                                }, 1000)
                                            }
                                        }).catch(() => {
                                            window.location = "%s";
                                        });
                                    } else if (result.dismiss === "cancel") {
                                        swal.fire("%s", "%s", "error");
                                    }
                                });
                            })
                        </script>',
                    $model->id,
                    __('main.ask-cancel-view-to-doctor'),
                    ($model->patent?$model->patient->name:$model->name),
                    __('main.yes'),
                    __('main.no'),
                    route(config('system.admin.name').'booking_operations',['booking'=>$model->id,'operation'=>'view_to_doctor_cancel']),
                    __('main.success'),
                    __('main.successful_process'),
                    route('admin.view_to_doctor_today_bookings.index'),
                    route('admin.view_to_doctor_today_bookings.index'),
                    __('main.canceled'),
                    __('main.no_action_done')

                );
                /*
                $finish_at_doctor  = sprintf('<a data-id="'.$model->id.'" id="finish_at_doctor_'.$model->id.'" class="SpeakerDelete btn btn-sm btn-clean btn-icon btn-icon-md"  title="%s"><i class="la la-share"></i></a>',__('main.finish_at_doctor'));
                $finish_at_doctor.=sprintf('
                        <script defer>
                            $("#finish_at_doctor_%s").on("click",(e)=>{
                                swal.fire({
                                    title: "%s",
                                    text: "%s",
                                    type: "info",
                                    showCancelButton: true,
                                    confirmButtonText: "%s",
                                    cancelButtonText: "%s",
                                    reverseButtons: true
                                }).then(function(result){
                                    if (result.value) {
                                        axios.get("%s").then((res) => {
                                            if (res.data.success) {
                                                swal.fire("%s", "%s", "success");
                                                setTimeout(() => {
                                                    window.location = "%s";
                                                }, 1000)
                                            }
                                        }).catch(() => {
                                            window.location = "%s";
                                        });
                                    } else if (result.dismiss === "cancel") {
                                        swal.fire("%s", "%s", "error");
                                    }
                                });
                            })
                        </script>',
                    $model->id,
                    __('main.ask-finish-at-doctor'),
                    ($model->patent?$model->patient->name:$model->name),
                    __('main.yes'),
                    __('main.no'),
                    route(config('system.admin.name').'booking_operations',['booking'=>$model->id,'operation'=>'finish_at_doctor']),
                    __('main.success'),
                    __('main.successful_process'),
                    route('admin.view_to_doctor_today_bookings.index'),
                    route('admin.view_to_doctor_today_bookings.index'),
                    __('main.canceled'),
                    __('main.no_action_done')

                );
                */
                return $cancel_attendance;
            })
            ->rawColumns(['checkbox','name','type','actions'])
            ->setRowAttr([
                'style' => function($model){
                    $background=$model->patientType?$model->patientType->color." !important":"";
                    return "background-color:".$background;
                },
            ]);
    }

    /**
     * Get query source of dataTable.
     *
     * @param \App\Booking $model
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function query(Booking $model)
    {
        $query = $model->whereNotNull('view_to_doctor_at')->where('appointment_date',date("Y-m-d"))->with(['clinic','attendanceStatus','patient','patientType'])->select('bookings.*')->orderBy('bookings.view_to_doctor_at','ASC')->newQuery();

        return $query;
    }

    /**
     * Optional method if you want to use html builder.
     *
     * @return \Yajra\DataTables\Html\Builder
     */
    public function html()
    {
        //$this->order_column=6;
        return $this->builder()
            ->setTableId('Booking-table')
            ->columns($this->getColumns())
            ->minifiedAjax()
            ->buttons($this->getButtons())
            ->parameters($this->getCustomBuilderParameters([1,2], [], GetLanguage() == 'ar'));
    }

    /**
     * Get columns.
     *
     * @return array
     */
    protected function getColumns()
    {
        return [
            Column::computed('checkbox', $this->getTitleCheckboxHtml())->width(15)->printable(false),
            Column::make('name', 'name')->title(trans('main.name')),
            Column::make('patientType.name', 'patientType.name')->title(trans('main.patient_type')),
            Column::make('slot_number', 'slot_number')->title(trans('main.visit_number')),
            Column::make('actions', 'actions')->title(trans('main.actions'))->searchable(false)->orderable(false)->printable(false),
        ];
    }

    /**
     * Get filename for export.
     *
     * @return string
     */
    protected function filename()
    {
        return 'Bookings_' . date('YmdHis');
    }
}
