<?php

use App\Domain\Users\Entities\User;
use Kreait\Firebase;
use Kreait\Firebase\Exception\InvalidArgumentException;
use Kreait\Firebase\Messaging\CloudMessage;

/**
 * Firebase Publish Notification.
 *
 * @param  mixed  $token        user token in fire base.
 * @param  array  $notification notification data ex: [ 'title' => 'Test Title', 'body' => 'Test Body', 'image' => asset('images/app_logo.png'), ]
 * @return array  $data         firebase data ex: [ 'target' => 'leads', 'target_id' => 1, ]
 */
function firebasePublish($user, $notification, $data)
{
    try {
        $token = null;

        if (!($user instanceof \App\User)) {
            $user = \App\User::find($user);
        }

        if (!$user) {
            throw new \Exception("Invalid User Passed");
        }

        if (!is_null($user->fcm_token)) {
            $token = $user->fcm_token;
        }

        if (is_null($token)) {
            throw new \Exception("Fire Base Token For User {$user->name}");
        }
        if (GetSettingByKey('firebase_credentials')) {
            $firebase= storage_path("app/public/" . GetSettingByKey('firebase_credentials'));
        } else {
            throw new \Exception("Fire Base credentials is not set");
        }

        $messaging = (new Firebase\Factory())->withServiceAccount($firebase)->createMessaging();

        $message = CloudMessage::withTarget('token', $token)->withNotification($notification)->withData($data);

        $response = $messaging->send($message);

        return [
            'success' => true,
            'response' => $response,
        ];
    } catch (\Exception $e) {
        logger()->error(['firebase_error' => $e->getMessage()]);
        return [
            'success' => false,
            'response' => $e->getMessage(),
        ];
    }
}
