<?php

namespace App\Http\Controllers\Admin\Resource;

use App\Datatables\BabyNameDataTables;
use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\BabyNameRequest;
use App\Repositories\Contract\BabyNameRepository;
use Illuminate\Http\Request;

class BabyNameController extends Controller
{
    /**
     * View Path.
     *
     * @var string
     */
    protected $viewPath = 'backend.babies_names';

    /**
     * Resource Route.
     *
     * @var string
     */
    protected $resourceRoute = 'admin.babies_names';

    /**
     * @param BabyNameRepository $repository
     */
    public function __construct(BabyNameRepository $repository)
    {
        $this->repository = $repository;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(BabyNameDataTables $dataTable)
    {
        return $dataTable->render("{$this->viewPath}.index", [
            'title' =>  __('main.babies_names'),
        ]);
    }

    public function create()
    {
        return view("{$this->viewPath}.create", [
            'title' => __('main.add')  . ' ' . __('main.baby_name'),
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param Request $request
     * @return Response
     */
    public function store(BabyNameRequest $request)
    {
        $data = $request->all();

        $store = $this->repository->create($data);
        if (!$store) {
            return $this->apiResponse(__('main.faild_create'), true, 422);
        }
        return $this->apiResponse($store, true, 200);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $show = $this->repository->find($id);
        if ($show) {
            return view("{$this->viewPath}.show", [
                'title' => __('main.show') . ' ' . __('main.baby_name').' : ' . $show->name_val,
                'show' => $show,
            ]);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        $object = $this->repository->find($id);
        if ($object) {
            return view("{$this->viewPath}.edit", [
                'title' => __('main.edit') . ' ' . ' ' . __('main.baby_name').' : ' . $object->name_val,
                'edit' => $object,
            ]);
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(BabyNameRequest $request, $id)
    {
        $data=$request->all();

        $update = $this->repository->update($id,$data);

        if (!$update) {
            return $this->apiResponse(__('main.faild_update'), true, 422);
        }

        return $this->apiResponse($update, true, 200);
    }
}
