<?php

namespace App\Http\Controllers\Api;

use App\Helpers\Classes\UploadHelper;
use App\Http\Controllers\Controller;
use App\Http\Requests\Api\LoginRequest;
use App\Http\Requests\Api\ParentUpdateProfileRequest;
use App\Http\Requests\Api\UserChangePasswordRequest;
use App\Http\Requests\Api\UserRequest;
use App\Http\Resources\UserResource;
use App\Repositories\Contract\ParentRepository;
use App\Repositories\Contract\PatientRepository;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class UserController extends Controller
{
    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(UserRequest $request,User $user)
    {
        $request["password"]=Hash::make($request['password']);

        $request['type']="user";

        $requestData=$request->all();

        $user = $user->create($requestData);
        if ($user) {
            Auth::login($user);
            $token = Auth::user()->createToken(env('APP_KEY'))->accessToken;
            $data["token"]=$token;
            $data["user"]=new UserResource($user);
            return $this->apiResponse($data, true, 200);
        }
        return $this->apiResponse("Problem occures during the process. User not addedd", true, 406);
    }
    /**
     * login to account.
     *
     * @param  \Illuminate\Http\Reequest  $request
     * @return \Illuminate\Http\Response
     */
    public function login(LoginRequest $request)
    {

        // Login with phone
        $credentials=$request->except('fcm_token');

        // Login with secondary phone
        $credentialsSecondaryPhone = $credentials;
        $credentialsSecondaryPhone['secondary_phone'] = $credentialsSecondaryPhone['phone'];
        unset($credentialsSecondaryPhone['phone']);

        // Try login
        if (Auth::attempt($credentials) || Auth::attempt($credentialsSecondaryPhone)) {
            $token = Auth::user()->createToken(env('APP_KEY'))->accessToken;
        }
        else{
            return response()->json([
                'message' => 'Error In Email OR Password'
            ], 401);
        }
        $user = auth()->user();

        $user->fcm_token=$request->fcm_token;

        $user->save();

        $data["token"] = $token;

        $data["user"]=new UserResource($user);

        return $this->apiResponse($data, true, 200);
    }
    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function profile()
    {
        $user = Auth::user();
        return $this->apiResponse(new UserResource($user), true, 200);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function updateProfile(UserRequest $request,PatientRepository $repository)
    {
        $id=Auth::user()->id;

        if($request->hasFile('user_image')){
            $image=$request->user_image;

            $dir="register_image";

            $uploaded_image=UploadHelper::Upload($image,$dir);

            $request['image']=$uploaded_image;
        }

        $data=$request->all();

        $update = $repository->update($id,$data);

        if ($update) {
            return $this->apiResponse(new UserResource($update), true, 200);
        }
        return $this->apiResponse("Problem occures during the process. User not addedd", true, 422);
    }
    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function change_password(UserChangePasswordRequest $request){
        $user=Auth::user();

        $user->password=Hash::make($request['password']);

        $user->save();

        if ($user) {
            return $this->apiResponse(new UserResource($user), true, 200);
        }
        return $this->apiResponse("failed to change password", true, 422);
    }

}
