<?php

namespace App\Providers;

use Illuminate\Support\ServiceProvider;

class RepositoryServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Repositories Array With Interface as a Key and Eloquent as a Value.
     *
     * @var array
     */
    private $repositories = [
        \App\Repositories\Contract\AdminRepository::class => \App\Repositories\Eloquent\EloquentAdminRepository::class,
        \App\Repositories\Contract\OccupationRepository::class => \App\Repositories\Eloquent\EloquentOccupationRepository::class,
        \App\Repositories\Contract\LocationRepository::class => \App\Repositories\Eloquent\EloquentLocationRepository::class,
        \App\Repositories\Contract\PatientTypeRepository::class => \App\Repositories\Eloquent\EloquentPatientTypeRepository::class,
        \App\Repositories\Contract\ClinicRepository::class => \App\Repositories\Eloquent\EloquentClinicRepository::class,
        \App\Repositories\Contract\BookingRepository::class => \App\Repositories\Eloquent\EloquentBookingRepository::class,
        \App\Repositories\Contract\ApplicationSettingRepository::class => \App\Repositories\Eloquent\EloquentApplicationSettingRepository::class,
        \App\Repositories\Contract\PatientRepository::class => \App\Repositories\Eloquent\EloquentPatientRepository::class,
        \App\Repositories\Contract\OperationRepository::class => \App\Repositories\Eloquent\EloquentOperationRepository::class,
        \App\Repositories\Contract\AttendanceStatusRepository::class => \App\Repositories\Eloquent\EloquentAttendanceStatusRepository::class,
        \App\Repositories\Contract\ReceptionistRepository::class => \App\Repositories\Eloquent\EloquentReceptionistRepository::class,
        \App\Repositories\Contract\AnswerQuestionRepository::class=> \App\Repositories\Eloquent\EloquentAnswerQuestionRepository::class,
        \App\Repositories\Contract\BabyNameRepository::class=> \App\Repositories\Eloquent\EloquentBabyNameRepository::class,
        \App\Repositories\Contract\GalleryRepository::class=> \App\Repositories\Eloquent\EloquentGalleryRepository::class,
        \App\Repositories\Contract\HospitalBagListRepository::class=> \App\Repositories\Eloquent\EloquentHospitalBagListRepository::class,
        \App\Repositories\Contract\ChildrenRepository::class=> \App\Repositories\Eloquent\EloquentChildrenRepository::class,
        \App\Repositories\Contract\ReviewRepository::class=> \App\Repositories\Eloquent\EloquentReviewRepository::class,
        \App\Repositories\Contract\NewsRepository::class=> \App\Repositories\Eloquent\EloquentNewsRepository::class,
        \App\Repositories\Contract\EnableAppointmentRepository::class=> \App\Repositories\Eloquent\EloquentEnableAppointmentRepository::class,
        \App\Repositories\Contract\OperationLocationRepository::class=> \App\Repositories\Eloquent\EloquentOperationLocationRepository::class,

    ];

    /**
     * Bootstrap services.
     *
     * @return void
     */
    public function boot()
    {
        /**
         * Bind all repositories to application.
         */
        foreach ($this->repositories as $interface => $eloquent) {
            $this->app->singleton($interface, $eloquent);
        }
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return array_keys($this->repositories);
    }
}
