<?php

namespace App\Repositories\Eloquent;

use App\Clinic;
use App\Repositories\Abstracts\RepositoryAbstract;
use App\Repositories\Contract\ClinicRepository;
use Illuminate\Database\Eloquent\Model;

class EloquentClinicRepository extends RepositoryAbstract implements ClinicRepository
{
    /**
     * @inheritDoc
     */
    public function entity(): string
    {
        return Clinic::class;
    }
    /**
     * Create New Entity.
     *
     * @param  array $data
     * @return Model
     */
    public function create(array $data) : Model
    {
        $entity=Parent::create($data);

        if(isset($data['working_days'])){
            foreach ($data['working_days'] as$key=>$value){
                $entity->workingDays()->create($value);
            }
        }
        $patient_type_price=[];
        foreach ($data['patient_type_price'] as$key=>$value){

            $patient_type_price[$value['patient_type_id']]=['price'=>$value['price']];
        }

        $entity->patientTypes()->sync($patient_type_price);

        return $entity;
    }
    /**
     * Update Entity.
     *
     * @param  integer $id
     * @param  array   $data
     * @return Model
     */
    public function update(int $id, array $data): Model
    {
        $entity= parent::update($id, $data);
        if(isset($data['working_days'])){
            $entity->workingDays()->delete();
            foreach ($data['working_days'] as$key=>$value){
                $entity->workingDays()->create($value);
            }
        }
        $patient_type_price=[];
        foreach ($data['patient_type_price'] as$key=>$value){
            $patient_type_price[$value['patient_type_id']]=['price'=>$value['price']];
        }
        $entity->patientTypes()->sync($patient_type_price);
        return $entity;
    }
}
