<?php

namespace App;

use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Passport\HasApiTokens;

class User extends Authenticatable
{
    use Notifiable,HasApiTokens;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name', 'email', 'password','phone','type','date_of_birth','nationality','location_id','occupation','notes','image','fcm_token','facebook_token','google_token','apple_token','secondary_phone'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];
    /************************************************************************/
    /****************************** Relations *******************************/
    /************************************************************************/
    /**
     * Location Relationship.
     *
     * @return BelongsTo
     **/

    public function location() : BelongsTo
    {
        return $this->belongsTo(Locations::class,'location_id','id');
    }
    /**
     * bookings Relationship.
     *
     * @return BelongsTo
     **/
    public function bookings() : HasMany
    {
        return $this->hasMany(Booking::class,'patient_id','id');
    }
    /**
     * operations Relationship.
     *
     * @return HasMany
     **/
    public function operations() : HasMany
    {
        return $this->hasMany(Operation::class,'patient_id','id');
    }
    /**
     * userNotifications Relationship.
     *
     * @return HasMany
     **/
    public function userNotifications() : HasMany
    {
        return $this->hasMany(Notification::class,'user_id','id');
    }

}
